==> istio-model-v1beta1-5.12.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRetryBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HTTPRetryBuilder extends io.fabric8.istio.api.networking.v1beta1.HTTPRetryFluentImpl<io.fabric8.istio.api.networking.v1beta1.HTTPRetryBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1beta1.HTTPRetry,io.fabric8.istio.api.networking.v1beta1.HTTPRetryBuilder>{
  public HTTPRetryBuilder() {
    this(false);
  }
  public HTTPRetryBuilder(java.lang.Boolean validationEnabled) {
    this(new HTTPRetry(), validationEnabled);
  }
  public HTTPRetryBuilder(io.fabric8.istio.api.networking.v1beta1.HTTPRetryFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPRetryBuilder(io.fabric8.istio.api.networking.v1beta1.HTTPRetryFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HTTPRetry(), validationEnabled);
  }
  public HTTPRetryBuilder(io.fabric8.istio.api.networking.v1beta1.HTTPRetryFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.HTTPRetry instance) {
    this(fluent, instance, false);
  }
  public HTTPRetryBuilder(io.fabric8.istio.api.networking.v1beta1.HTTPRetryFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.HTTPRetry instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAttempts(instance.getAttempts()); 
    fluent.withPerTryTimeout(instance.getPerTryTimeout()); 
    fluent.withRetryOn(instance.getRetryOn()); 
    fluent.withRetryRemoteLocalities(instance.getRetryRemoteLocalities()); 
    this.validationEnabled = validationEnabled; 
  }
  public HTTPRetryBuilder(io.fabric8.istio.api.networking.v1beta1.HTTPRetry instance) {
    this(instance,false);
  }
  public HTTPRetryBuilder(io.fabric8.istio.api.networking.v1beta1.HTTPRetry instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAttempts(instance.getAttempts()); 
    this.withPerTryTimeout(instance.getPerTryTimeout()); 
    this.withRetryOn(instance.getRetryOn()); 
    this.withRetryRemoteLocalities(instance.getRetryRemoteLocalities()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1beta1.HTTPRetryFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1beta1.HTTPRetry build() {
    HTTPRetry buildable = new HTTPRetry(fluent.getAttempts(),fluent.getPerTryTimeout(),fluent.getRetryOn(),fluent.getRetryRemoteLocalities());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRetryBuilder that = (HTTPRetryBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRetryBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HTTPRetryBuilder extends HTTPRetryFluentImpl<HTTPRetryBuilder> implements VisitableBuilder<HTTPRetry,HTTPRetryBuilder>{
  public HTTPRetryBuilder() {
    this(false);
  }
  public HTTPRetryBuilder(Boolean validationEnabled) {
    this(new HTTPRetry(), validationEnabled);
  }
  public HTTPRetryBuilder(HTTPRetryFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPRetryBuilder(HTTPRetryFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HTTPRetry(), validationEnabled);
  }
  public HTTPRetryBuilder(HTTPRetryFluent<?> fluent,HTTPRetry instance) {
    this(fluent, instance, false);
  }
  public HTTPRetryBuilder(HTTPRetryFluent<?> fluent,HTTPRetry instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAttempts(instance.getAttempts()); 
    fluent.withPerTryTimeout(instance.getPerTryTimeout()); 
    fluent.withRetryOn(instance.getRetryOn()); 
    fluent.withRetryRemoteLocalities(instance.getRetryRemoteLocalities()); 
    this.validationEnabled = validationEnabled; 
  }
  public HTTPRetryBuilder(HTTPRetry instance) {
    this(instance,false);
  }
  public HTTPRetryBuilder(HTTPRetry instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAttempts(instance.getAttempts()); 
    this.withPerTryTimeout(instance.getPerTryTimeout()); 
    this.withRetryOn(instance.getRetryOn()); 
    this.withRetryRemoteLocalities(instance.getRetryRemoteLocalities()); 
    this.validationEnabled = validationEnabled; 
  }
  HTTPRetryFluent<?> fluent;
  Boolean validationEnabled;
  public HTTPRetry build() {
    HTTPRetry buildable = new HTTPRetry(fluent.getAttempts(),fluent.getPerTryTimeout(),fluent.getRetryOn(),fluent.getRetryRemoteLocalities());
    return buildable;
  }
  
}
